Esycord Discord API Plugin
--------------------------------------------
This is a very beginner friendly package
for all those who wanna make a Discord
bot but dont have much eLevelerience with
Discord's API Wrapper.

Copyright (c) 2024 Aayush Srivastava

Licensed under the MIT License.


Future updates will include Voice Client fuctions,
Automod and other features.
